@@ -6,20 +6,57 @@ image.SpatialGridDataFrame = function(x, attr = 1, xcol = 1, ycol = 2,
                 col = heat.colors(12), 
 		red=NULL, green=NULL, blue=NULL, axes = FALSE, xlim = NULL, 
 		ylim = NULL, add = FALSE, ..., asp = NA, 
-		setParUsrBB=FALSE) {
+		setParUsrBB=FALSE, interpolate = FALSE, angle = 0,
+                useRasterImage=TRUE) {
 
 	if (!add)
 		plot(as(x, "Spatial"),
 			xlim = xlim, ylim = ylim, axes = axes, asp = asp, ..., 
 			setParUsrBB=setParUsrBB)
-	if (is.null(red)) 
+        if (exists("rasterImage") && useRasterImage) {
+            bb <- bbox(x)
+            scl <- function(x) (x - min(x, na.rm  = TRUE)) /
+                diff(range(x, na.rm = TRUE))
+        }
+	if (is.null(red)) {
+            if (exists("rasterImage") && useRasterImage) {
+                x <- x[attr]
+                NAs <- is.na(x[[1]])
+                m <-  scl(t(matrix(x[[1]], x@grid@cells.dim[1],
+                    x@grid@cells.dim[2])))
+                m <- matrix(col[as.vector(m) * (length(col)-1) + 1], 
+                    nrow(m), ncol(m))
+                ## if missing, set to white
+                m[is.na(m)] <- rgb(1, 1, 1)
+                rasterImage(m, bb[1,1], bb[2,1], bb[1,2], bb[2,2],
+                    interpolate = interpolate, angle = angle)
+            } else {
 		image(as.image.SpatialGridDataFrame(x[attr], xcol, ycol), 
                   add = TRUE, col = col, ...)
-	else {
-		if (is.null(green) || is.null(blue)) 
-			stop("all colour bands must be given")
+            }
+	} else {
+	    if (is.null(green) || is.null(blue)) 
+		stop("all colour bands must be given")
 # modified to handle NAs in input (typical for coercion of Spatial Pixels
 # to Spatial Grid)
+            if (exists("rasterImage") && useRasterImage) {
+                xd <- x@data[, c(red, green, blue)]
+                NAs <- is.na(xd[, 1]) | is.na(xd[, 2]) | is.na(xd[, 3])
+                if (any(NAs))
+                    xd <- xd[!NAs, ]
+                ## create RGBs (using alpha=1 by default)
+                RGBs <- rgb(xd, max = 255)
+                if (any(NAs)) {
+                    z <- rep(NA, length(NAs))
+                    z[!NAs] <- RGBs
+                    RGBs <- z
+                }
+                cv <- coordinatevalues(getGridTopology(x))
+                m <- t(matrix(RGBs, x@grid@cells.dim[1], 
+                    x@grid@cells.dim[2], byrow = FALSE))
+                rasterImage(m, bb[1,1], bb[2,1], bb[1,2], bb[2,2],
+                    interpolate = interpolate, angle = angle)
+            } else {
 		xd <- x@data[,c(red, green, blue)]
 		NAs <- is.na(xd[,1]) | is.na(xd[,2]) | is.na(xd[,3])
 		if (any(NAs)) xd <- xd[!NAs,]
@@ -35,6 +72,7 @@ image.SpatialGridDataFrame = function(x, attr = 1, xcol = 1, ycol = 2,
 			x@grid@cells.dim[2], byrow=FALSE)
 		res <- list(x=cv[[xcol]], y=sort(cv[[ycol]]), z=m[,ncol(m):1])
 		image(res, col=levels(fcols), add = TRUE, ...)
+            }
 	}
 }
 
